==> tagmemo_0_1.tar.gz: tagmemo/class/memo.php <==
<?php
/**
*֥ץ֥ȤΥ饹
* @package Persistence
*/
/**
* XoopsTableObjectѾ
*/
include_once dirname(__FILE__).'/xoopstableobject.php';

/**
* Υǡ֥
* @package Persistence
* @author twodash <twodash@twodash.net>
*/
class TagmemoMemo extends XoopsTableObject
{
/**
* 󥹥ȥ饯
*/
	function TagmemoMemo()
	{
		$this->XoopsObject();
		$this->initVar('tagmemo_id', XOBJ_DTYPE_INT, null, true);
		$this->initVar('uid', XOBJ_DTYPE_INT, null, true);
		$this->initVar('title', XOBJ_DTYPE_TXTBOX, null, true, 120);
		$this->initVar('content', XOBJ_DTYPE_TXTAREA, null, true);
		$this->initVar('timestamp', XOBJ_DTYPE_INT, null, true);
		$this->initVar('public', XOBJ_DTYPE_INT, null, true);
		//ץ饤ޥ꡼
		$this->setKeyFields(array('tagmemo_id'));

		//AUTO_INCREMENT°Υե
		// - ĤΥơ֥ˤϡAUTO_INCREMENT°ĥեɤ
		//   ĤʤǤ
		$this->setAutoIncrementField('tagmemo_id');
	} 
}

/**
* Υ֥ȥϥɥ
* @package Persistence
* @author twodash <twodash@twodash.net>
*/
class TagmemoMemoHandler extends XoopsTableObjectHandler
{
/**
* 󥹥ȥ饯
*/
    function TagmemoMemoHandler(&$db)
    {
    ////////////////////////////////////////
    // ƥ饹ʬ()
    ////////////////////////////////////////

        //ƥ饹Υ󥹥ȥ饯ƽ
        $this->XoopsTableObjectHandler($db);
        
    ////////////////////////////////////////
    // 饹ͭʬ
    ////////////////////////////////////////

        //ϥɥоݥơ֥̾
        $this->tableName = $this->db->prefix('tagmemo');

        //Ϣ饹̾Τʸ
        // - ɸΥ͡ߥ󥰤˽򤷤Ƥˤ
     $this->objectClassName = 'tagmemomemo';
    }
	//ߴΤĤƤߤ
    function &getInstance(&$db)
    {
        static $instance;
        if (!isset($instance)) {
            $instance = new TagmemoMemoHandler($db);
        }
        return $instance;
    }
/**
*Ѥò
* @param CriteriaElement
* @return array
*/
	function &getMemo($criteria=null,$having=""){
		$fieldlist=" main.tagmemo_id, uid, title, content, public, timestamp";
		if($criteria == null){
			$criteria = new CriteriaCompo;
		}
		$criteria->setGroupby($fieldlist);
		$joindef = new XoopsJoinCriteria($this->db->prefix('tagmemo_rel'), 'tagmemo_id','tagmemo_id', 'LEFT','main','rel');
		return parent::getObjects($criteria, true, $fieldlist, false, $joindef,$having);	
	}
}
?>

==> tagmemo_0.2.tar.gz: tagmemo/class/memo.php <==
<?php
/**
*֥ץ֥ȤΥ饹
* @package Persistence
*/
/**
* XoopsTableObjectѾ
*/
include_once dirname(__FILE__).'/xoopstableobject.php';

/**
* Υǡ֥
* @package Persistence
* @author twodash <twodash@twodash.net>
*/
class TagmemoMemo extends XoopsTableObject
{
/**
* 󥹥ȥ饯
*/
	function TagmemoMemo()
	{
		$this->XoopsObject();
		$this->initVar('tagmemo_id', XOBJ_DTYPE_INT, null, true);
		$this->initVar('uid', XOBJ_DTYPE_INT, null, true);
		$this->initVar('title', XOBJ_DTYPE_TXTBOX, null, true, 120);
		$this->initVar('content', XOBJ_DTYPE_TXTAREA, null, true);
		$this->initVar('timestamp', XOBJ_DTYPE_INT, null, true);
		$this->initVar('public', XOBJ_DTYPE_INT, null, true);
		//ץ饤ޥ꡼
		$this->setKeyFields(array('tagmemo_id'));

		//AUTO_INCREMENT°Υե
		// - ĤΥơ֥ˤϡAUTO_INCREMENT°ĥեɤ
		//   ĤʤǤ
		$this->setAutoIncrementField('tagmemo_id');
	} 
}

/**
* Υ֥ȥϥɥ
* @package Persistence
* @author twodash <twodash@twodash.net>
*/
class TagmemoMemoHandler extends XoopsTableObjectHandler
{
/**
* 󥹥ȥ饯
*/
    function TagmemoMemoHandler(&$db)
    {
    ////////////////////////////////////////
    // ƥ饹ʬ()
    ////////////////////////////////////////

        //ƥ饹Υ󥹥ȥ饯ƽ
        $this->XoopsTableObjectHandler($db);
        
    ////////////////////////////////////////
    // 饹ͭʬ
    ////////////////////////////////////////

        //ϥɥоݥơ֥̾
        $this->tableName = $this->db->prefix('tagmemo');
		$this->tableAlias = 'main';
        //Ϣ饹̾Τʸ
        // - ɸΥ͡ߥ󥰤˽򤷤Ƥˤ
     $this->objectClassName = 'tagmemomemo';
    }
	//ߴΤĤƤߤ
    function &getInstance(&$db)
    {
        static $instance;
        if (!isset($instance)) {
            $instance = new TagmemoMemoHandler($db);
        }
        return $instance;
    }
/**
*Ѥò
* @param CriteriaElement
* @return array
*/
	function &getMemo($criteria=null,$having=""){
		$fieldlist=" main.tagmemo_id, uid, title, content, public, timestamp";
		if($criteria == null){
			$criteria = new CriteriaCompo;
		}
		$criteria->setGroupby($fieldlist);
		//$joindef = new XoopsJoinCriteria($this->db->prefix('tagmemo_rel'), 'tagmemo_id','tagmemo_id', 'LEFT','main','rel');
		$joindef = new XoopsJoinCriteria($this->db->prefix('tagmemo_rel'), 'tagmemo_id','tagmemo_id', 'LEFT','rel');
		return parent::getObjects($criteria, true, $fieldlist, false, $joindef,$having);	
	}
}
?>
